"""
    Wirepas Mesh Messaging
    ======================

    .. Copyright:
        Copyright 2020 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""



import sys, os
sys.path.append(os.path.dirname(__file__))

# Protobuf files will be compiled here
from .error_pb2 import *
from .wp_global_pb2 import *
from .config_message_pb2 import *
from .otap_message_pb2 import *
from .generic_message_pb2 import *
from .data_message_pb2 import *


"""
    Request
    =======

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

import random
from .proto import RequestHeader


class Request(object):
    """
    Request

    Attributes:
        sink_id(str): sink identifier
        req_id (int): identifier to help distinguish a response/request pair
    """

    # pylint: disable=unused-argument
    def __init__(self, sink_id=None, req_id=None, **kwargs):
        super(Request, self).__init__()
        self.sink_id = sink_id
        if req_id is None:
            req_id = random.getrandbits(64)
        self.req_id = req_id

    def __str__(self):
        return str(self.__dict__)

    @property
    def payload(self):
        """ Implement how to serialize child Event classes """
        raise NotImplementedError()

    def _load_request_header(self, request):
        header = request.header
        header.req_id = self.req_id

        if self.sink_id is not None:
            header.sink_id = str(self.sink_id)

    @staticmethod
    def _parse_request_header(header):
        """
        Parses the header details from a protobuff message

        Args:
            header (proto): proto buff message

        Returns:
            A dictionary with the header details
        """
        d = dict()
        d["req_id"] = header.req_id
        if header.HasField("sink_id"):
            d["sink_id"] = header.sink_id
        else:
            d["sink_id"] = None

        return d



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: generic_message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import config_message_pb2 as config__message__pb2
import data_message_pb2 as data__message__pb2
import otap_message_pb2 as otap__message__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='generic_message.proto',
  package='wirepas.proto.gateway_api',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15generic_message.proto\x12\x19wirepas.proto.gateway_api\x1a\x14\x63onfig_message.proto\x1a\x12\x64\x61ta_message.proto\x1a\x12otap_message.proto\"\x89\x0b\n\x0eWirepasMessage\x12<\n\x0cstatus_event\x18\x01 \x01(\x0b\x32&.wirepas.proto.gateway_api.StatusEvent\x12\x41\n\x0fget_configs_req\x18\x02 \x01(\x0b\x32(.wirepas.proto.gateway_api.GetConfigsReq\x12\x43\n\x10get_configs_resp\x18\x03 \x01(\x0b\x32).wirepas.proto.gateway_api.GetConfigsResp\x12?\n\x0eset_config_req\x18\x04 \x01(\x0b\x32\'.wirepas.proto.gateway_api.SetConfigReq\x12\x41\n\x0fset_config_resp\x18\x05 \x01(\x0b\x32(.wirepas.proto.gateway_api.SetConfigResp\x12\x41\n\x0fsend_packet_req\x18\x06 \x01(\x0b\x32(.wirepas.proto.gateway_api.SendPacketReq\x12\x43\n\x10send_packet_resp\x18\x07 \x01(\x0b\x32).wirepas.proto.gateway_api.SendPacketResp\x12M\n\x15packet_received_event\x18\x08 \x01(\x0b\x32..wirepas.proto.gateway_api.PacketReceivedEvent\x12T\n\x19get_scratchpad_status_req\x18\t \x01(\x0b\x32\x31.wirepas.proto.gateway_api.GetScratchpadStatusReq\x12V\n\x1aget_scratchpad_status_resp\x18\n \x01(\x0b\x32\x32.wirepas.proto.gateway_api.GetScratchpadStatusResp\x12M\n\x15upload_scratchpad_req\x18\x0b \x01(\x0b\x32..wirepas.proto.gateway_api.UploadScratchpadReq\x12O\n\x16upload_scratchpad_resp\x18\x0c \x01(\x0b\x32/.wirepas.proto.gateway_api.UploadScratchpadResp\x12O\n\x16process_scratchpad_req\x18\r \x01(\x0b\x32/.wirepas.proto.gateway_api.ProcessScratchpadReq\x12Q\n\x17process_scratchpad_resp\x18\x0e \x01(\x0b\x32\x30.wirepas.proto.gateway_api.ProcessScratchpadResp\x12\x45\n\x14get_gateway_info_req\x18\x0f \x01(\x0b\x32\'.wirepas.proto.gateway_api.GetGwInfoReq\x12G\n\x15get_gateway_info_resp\x18\x10 \x01(\x0b\x32(.wirepas.proto.gateway_api.GetGwInfoResp\x12h\n$set_scratchpad_target_and_action_req\x18\x11 \x01(\x0b\x32:.wirepas.proto.gateway_api.SetScratchpadTargetAndActionReq\x12j\n%set_scratchpad_target_and_action_resp\x18\x12 \x01(\x0b\x32;.wirepas.proto.gateway_api.SetScratchpadTargetAndActionResp\"(\n\x0f\x43ustomerMessage\x12\x15\n\rcustomer_name\x18\x01 \x02(\t\"\x8a\x01\n\x0eGenericMessage\x12:\n\x07wirepas\x18\x01 \x01(\x0b\x32).wirepas.proto.gateway_api.WirepasMessage\x12<\n\x08\x63ustomer\x18\x02 \x01(\x0b\x32*.wirepas.proto.gateway_api.CustomerMessage'
  ,
  dependencies=[config__message__pb2.DESCRIPTOR,data__message__pb2.DESCRIPTOR,otap__message__pb2.DESCRIPTOR,])




_WIREPASMESSAGE = _descriptor.Descriptor(
  name='WirepasMessage',
  full_name='wirepas.proto.gateway_api.WirepasMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_event', full_name='wirepas.proto.gateway_api.WirepasMessage.status_event', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_configs_req', full_name='wirepas.proto.gateway_api.WirepasMessage.get_configs_req', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_configs_resp', full_name='wirepas.proto.gateway_api.WirepasMessage.get_configs_resp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_config_req', full_name='wirepas.proto.gateway_api.WirepasMessage.set_config_req', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_config_resp', full_name='wirepas.proto.gateway_api.WirepasMessage.set_config_resp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_packet_req', full_name='wirepas.proto.gateway_api.WirepasMessage.send_packet_req', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_packet_resp', full_name='wirepas.proto.gateway_api.WirepasMessage.send_packet_resp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_received_event', full_name='wirepas.proto.gateway_api.WirepasMessage.packet_received_event', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_scratchpad_status_req', full_name='wirepas.proto.gateway_api.WirepasMessage.get_scratchpad_status_req', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_scratchpad_status_resp', full_name='wirepas.proto.gateway_api.WirepasMessage.get_scratchpad_status_resp', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_scratchpad_req', full_name='wirepas.proto.gateway_api.WirepasMessage.upload_scratchpad_req', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_scratchpad_resp', full_name='wirepas.proto.gateway_api.WirepasMessage.upload_scratchpad_resp', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_scratchpad_req', full_name='wirepas.proto.gateway_api.WirepasMessage.process_scratchpad_req', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_scratchpad_resp', full_name='wirepas.proto.gateway_api.WirepasMessage.process_scratchpad_resp', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_gateway_info_req', full_name='wirepas.proto.gateway_api.WirepasMessage.get_gateway_info_req', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_gateway_info_resp', full_name='wirepas.proto.gateway_api.WirepasMessage.get_gateway_info_resp', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_scratchpad_target_and_action_req', full_name='wirepas.proto.gateway_api.WirepasMessage.set_scratchpad_target_and_action_req', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_scratchpad_target_and_action_resp', full_name='wirepas.proto.gateway_api.WirepasMessage.set_scratchpad_target_and_action_resp', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=1532,
)


_CUSTOMERMESSAGE = _descriptor.Descriptor(
  name='CustomerMessage',
  full_name='wirepas.proto.gateway_api.CustomerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_name', full_name='wirepas.proto.gateway_api.CustomerMessage.customer_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1534,
  serialized_end=1574,
)


_GENERICMESSAGE = _descriptor.Descriptor(
  name='GenericMessage',
  full_name='wirepas.proto.gateway_api.GenericMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wirepas', full_name='wirepas.proto.gateway_api.GenericMessage.wirepas', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer', full_name='wirepas.proto.gateway_api.GenericMessage.customer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1577,
  serialized_end=1715,
)

_WIREPASMESSAGE.fields_by_name['status_event'].message_type = config__message__pb2._STATUSEVENT
_WIREPASMESSAGE.fields_by_name['get_configs_req'].message_type = config__message__pb2._GETCONFIGSREQ
_WIREPASMESSAGE.fields_by_name['get_configs_resp'].message_type = config__message__pb2._GETCONFIGSRESP
_WIREPASMESSAGE.fields_by_name['set_config_req'].message_type = config__message__pb2._SETCONFIGREQ
_WIREPASMESSAGE.fields_by_name['set_config_resp'].message_type = config__message__pb2._SETCONFIGRESP
_WIREPASMESSAGE.fields_by_name['send_packet_req'].message_type = data__message__pb2._SENDPACKETREQ
_WIREPASMESSAGE.fields_by_name['send_packet_resp'].message_type = data__message__pb2._SENDPACKETRESP
_WIREPASMESSAGE.fields_by_name['packet_received_event'].message_type = data__message__pb2._PACKETRECEIVEDEVENT
_WIREPASMESSAGE.fields_by_name['get_scratchpad_status_req'].message_type = otap__message__pb2._GETSCRATCHPADSTATUSREQ
_WIREPASMESSAGE.fields_by_name['get_scratchpad_status_resp'].message_type = otap__message__pb2._GETSCRATCHPADSTATUSRESP
_WIREPASMESSAGE.fields_by_name['upload_scratchpad_req'].message_type = otap__message__pb2._UPLOADSCRATCHPADREQ
_WIREPASMESSAGE.fields_by_name['upload_scratchpad_resp'].message_type = otap__message__pb2._UPLOADSCRATCHPADRESP
_WIREPASMESSAGE.fields_by_name['process_scratchpad_req'].message_type = otap__message__pb2._PROCESSSCRATCHPADREQ
_WIREPASMESSAGE.fields_by_name['process_scratchpad_resp'].message_type = otap__message__pb2._PROCESSSCRATCHPADRESP
_WIREPASMESSAGE.fields_by_name['get_gateway_info_req'].message_type = config__message__pb2._GETGWINFOREQ
_WIREPASMESSAGE.fields_by_name['get_gateway_info_resp'].message_type = config__message__pb2._GETGWINFORESP
_WIREPASMESSAGE.fields_by_name['set_scratchpad_target_and_action_req'].message_type = otap__message__pb2._SETSCRATCHPADTARGETANDACTIONREQ
_WIREPASMESSAGE.fields_by_name['set_scratchpad_target_and_action_resp'].message_type = otap__message__pb2._SETSCRATCHPADTARGETANDACTIONRESP
_GENERICMESSAGE.fields_by_name['wirepas'].message_type = _WIREPASMESSAGE
_GENERICMESSAGE.fields_by_name['customer'].message_type = _CUSTOMERMESSAGE
DESCRIPTOR.message_types_by_name['WirepasMessage'] = _WIREPASMESSAGE
DESCRIPTOR.message_types_by_name['CustomerMessage'] = _CUSTOMERMESSAGE
DESCRIPTOR.message_types_by_name['GenericMessage'] = _GENERICMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WirepasMessage = _reflection.GeneratedProtocolMessageType('WirepasMessage', (_message.Message,), {
  'DESCRIPTOR' : _WIREPASMESSAGE,
  '__module__' : 'generic_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.WirepasMessage)
  })
_sym_db.RegisterMessage(WirepasMessage)

CustomerMessage = _reflection.GeneratedProtocolMessageType('CustomerMessage', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMERMESSAGE,
  '__module__' : 'generic_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.CustomerMessage)
  })
_sym_db.RegisterMessage(CustomerMessage)

GenericMessage = _reflection.GeneratedProtocolMessageType('GenericMessage', (_message.Message,), {
  'DESCRIPTOR' : _GENERICMESSAGE,
  '__module__' : 'generic_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.GenericMessage)
  })
_sym_db.RegisterMessage(GenericMessage)


# @@protoc_insertion_point(module_scope)



"""
    Response
    ========

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

from .proto import ResponseHeader
from .gateway_result_code import GatewayResultCode


class Response(object):
    """
    Response

    Attributes:
        gw_id (str): unique gateway identifier
        sink_id(str): sink identifier
        req_id (int): identifier to help distinguish a response/request pair (same as in request)
        res(GatewayResultCode): result of the operation
    """

    # pylint: disable=unused-argument
    def __init__(self, req_id, gw_id, res, sink_id=None, **kwargs):
        super(Response, self).__init__()
        self.gw_id = gw_id
        self.sink_id = sink_id
        self.req_id = req_id
        self.res = res

    def __str__(self):
        return str(self.__dict__)

    @property
    def payload(self):
        """ Implement how to serialize child Event classes """
        raise NotImplementedError()

    def _load_response_header(self, response):
        """ Creates the generic messaging header """
        header = response.header
        header.req_id = self.req_id
        header.gw_id = str(self.gw_id)
        # No conversion needed as one to one mapping
        header.res = self.res.value

        if self.sink_id is not None:
            header.sink_id = str(self.sink_id)

    @staticmethod
    def _parse_response_header(header):
        """
        Parses the header details from a protobuff message

        Args:
            header (proto): proto buff message

        Returns:
            A dictionary with the header details
        """
        d = dict()
        d["req_id"] = header.req_id
        d["gw_id"] = header.gw_id
        d["res"] = GatewayResultCode(header.res)

        if header.HasField("sink_id"):
            d["sink_id"] = header.sink_id
        else:
            d["sink_id"] = None

        return d



"""
    Get gateway info
    ================

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

from .proto import GenericMessage

from .request import Request
from .response import Response

from .wirepas_exceptions import GatewayAPIParsingException


class GetGatewayInfoRequest(Request):
    """
    GetGatewayInfoRequest: Request to obtain the gateway config

    Attributes:
        req_id (int): unique request id
    """

    def __init__(self, req_id=None, **kwargs):
        super(GetGatewayInfoRequest, self).__init__(req_id=req_id, **kwargs)

    @classmethod
    def from_payload(cls, payload):
        message = GenericMessage()
        try:
            message.ParseFromString(payload)
        except Exception:
            # Any Exception is promoted to Generic API exception
            raise GatewayAPIParsingException(
                "Cannot parse GetGatewayInfoRequest payload"
            )

        d = Request._parse_request_header(message.wirepas.get_gateway_info_req.header)
        return cls(d["req_id"])

    @property
    def payload(self):
        message = GenericMessage()
        # Fill the request header
        get_gateway_info = message.wirepas.get_gateway_info_req
        self._load_request_header(get_gateway_info)

        return message.SerializeToString()


class GetGatewayInfoResponse(Response):
    """
    GetGatewayInfoResponse: Response to answer a GetGatewayInfoRequest

    Attributes:
        req_id (int): unique request id that this Response is associated
        gw_id (str): gw_id (str): gateway unique identifier
        res (GatewayResultCode): result of the operation
        current_time_s_epoch (int): current timestamp in ms relative to epoch
        gateway_model (string): gateway model (managed by gateway integrator)
        gateway_version (string): gateway version (managed by gateway integrator)
    """

    def __init__(
        self,
        req_id,
        gw_id,
        res,
        current_time_s_epoch,
        gateway_model=None,
        gateway_version=None,
        implemented_api_version=None,
        **kwargs
    ):
        super(GetGatewayInfoResponse, self).__init__(req_id, gw_id, res, **kwargs)
        self.current_time_s_epoch = current_time_s_epoch
        self.gateway_model = gateway_model
        self.gateway_version = gateway_version
        self.implemented_api_version = implemented_api_version

    @classmethod
    def from_payload(cls, payload):
        message = GenericMessage()
        try:
            message.ParseFromString(payload)
        except Exception:
            # Any Exception is promoted to Generic API exception
            raise GatewayAPIParsingException(
                "Cannot parse GetGatewayInfoResponse payload"
            )

        response = message.wirepas.get_gateway_info_resp

        d = Response._parse_response_header(response.header)

        return cls(
            d["req_id"],
            d["gw_id"],
            d["res"],
            current_time_s_epoch=response.info.current_time_s_epoch,
            gateway_model=response.info.gw_model,
            gateway_version=response.info.gw_version,
            implemented_api_version=response.info.implemented_api_version,
        )

    @property
    def payload(self):
        message = GenericMessage()

        response = message.wirepas.get_gateway_info_resp
        self._load_response_header(response)

        response.info.current_time_s_epoch = self.current_time_s_epoch

        if self.gateway_model is not None:
            response.info.gw_model = self.gateway_model

        if self.gateway_version is not None:
            response.info.gw_version = self.gateway_version

        if self.implemented_api_version is not None:
            response.info.implemented_api_version = self.implemented_api_version

        return message.SerializeToString()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wp_global.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import error_pb2 as error__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='wp_global.proto',
  package='wirepas.proto.gateway_api',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fwp_global.proto\x12\x19wirepas.proto.gateway_api\x1a\x0b\x65rror.proto\"0\n\rRequestHeader\x12\x0e\n\x06req_id\x18\x01 \x02(\x04\x12\x0f\n\x07sink_id\x18\x02 \x01(\t\"s\n\x0eResponseHeader\x12\x0e\n\x06req_id\x18\x01 \x02(\x04\x12\r\n\x05gw_id\x18\x02 \x02(\t\x12\x0f\n\x07sink_id\x18\x03 \x01(\t\x12\x31\n\x03res\x18\x04 \x02(\x0e\x32$.wirepas.proto.gateway_api.ErrorCode\"?\n\x0b\x45ventHeader\x12\r\n\x05gw_id\x18\x01 \x02(\t\x12\x0f\n\x07sink_id\x18\x02 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x03 \x02(\x04\"K\n\x0f\x46irmwareVersion\x12\r\n\x05major\x18\x01 \x02(\r\x12\r\n\x05minor\x18\x02 \x02(\r\x12\r\n\x05maint\x18\x03 \x02(\r\x12\x0b\n\x03\x64\x65v\x18\x04 \x02(\r*\x1d\n\nOnOffState\x12\x06\n\x02ON\x10\x01\x12\x07\n\x03OFF\x10\x02'
  ,
  dependencies=[error__pb2.DESCRIPTOR,])

_ONOFFSTATE = _descriptor.EnumDescriptor(
  name='OnOffState',
  full_name='wirepas.proto.gateway_api.OnOffState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ON', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=368,
  serialized_end=397,
)
_sym_db.RegisterEnumDescriptor(_ONOFFSTATE)

OnOffState = enum_type_wrapper.EnumTypeWrapper(_ONOFFSTATE)
ON = 1
OFF = 2



_REQUESTHEADER = _descriptor.Descriptor(
  name='RequestHeader',
  full_name='wirepas.proto.gateway_api.RequestHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='wirepas.proto.gateway_api.RequestHeader.req_id', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='wirepas.proto.gateway_api.RequestHeader.sink_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=107,
)


_RESPONSEHEADER = _descriptor.Descriptor(
  name='ResponseHeader',
  full_name='wirepas.proto.gateway_api.ResponseHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='wirepas.proto.gateway_api.ResponseHeader.req_id', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gw_id', full_name='wirepas.proto.gateway_api.ResponseHeader.gw_id', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='wirepas.proto.gateway_api.ResponseHeader.sink_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='res', full_name='wirepas.proto.gateway_api.ResponseHeader.res', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=224,
)


_EVENTHEADER = _descriptor.Descriptor(
  name='EventHeader',
  full_name='wirepas.proto.gateway_api.EventHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gw_id', full_name='wirepas.proto.gateway_api.EventHeader.gw_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='wirepas.proto.gateway_api.EventHeader.sink_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='wirepas.proto.gateway_api.EventHeader.event_id', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=289,
)


_FIRMWAREVERSION = _descriptor.Descriptor(
  name='FirmwareVersion',
  full_name='wirepas.proto.gateway_api.FirmwareVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='wirepas.proto.gateway_api.FirmwareVersion.major', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor', full_name='wirepas.proto.gateway_api.FirmwareVersion.minor', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maint', full_name='wirepas.proto.gateway_api.FirmwareVersion.maint', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dev', full_name='wirepas.proto.gateway_api.FirmwareVersion.dev', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=366,
)

_RESPONSEHEADER.fields_by_name['res'].enum_type = error__pb2._ERRORCODE
DESCRIPTOR.message_types_by_name['RequestHeader'] = _REQUESTHEADER
DESCRIPTOR.message_types_by_name['ResponseHeader'] = _RESPONSEHEADER
DESCRIPTOR.message_types_by_name['EventHeader'] = _EVENTHEADER
DESCRIPTOR.message_types_by_name['FirmwareVersion'] = _FIRMWAREVERSION
DESCRIPTOR.enum_types_by_name['OnOffState'] = _ONOFFSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestHeader = _reflection.GeneratedProtocolMessageType('RequestHeader', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTHEADER,
  '__module__' : 'wp_global_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.RequestHeader)
  })
_sym_db.RegisterMessage(RequestHeader)

ResponseHeader = _reflection.GeneratedProtocolMessageType('ResponseHeader', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEHEADER,
  '__module__' : 'wp_global_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.ResponseHeader)
  })
_sym_db.RegisterMessage(ResponseHeader)

EventHeader = _reflection.GeneratedProtocolMessageType('EventHeader', (_message.Message,), {
  'DESCRIPTOR' : _EVENTHEADER,
  '__module__' : 'wp_global_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.EventHeader)
  })
_sym_db.RegisterMessage(EventHeader)

FirmwareVersion = _reflection.GeneratedProtocolMessageType('FirmwareVersion', (_message.Message,), {
  'DESCRIPTOR' : _FIRMWAREVERSION,
  '__module__' : 'wp_global_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.FirmwareVersion)
  })
_sym_db.RegisterMessage(FirmwareVersion)


# @@protoc_insertion_point(module_scope)



"""
    Received data
    =============

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

from .proto import GenericMessage

from .event import Event
from .wirepas_exceptions import GatewayAPIParsingException


class ReceivedDataEvent(Event):
    """
    ReceivedDataEvent: Event generated when a message is received from Wirepas network

    Attributes:
        gw_id (str): gw_id (str): gateway unique identifier
        sink_id (str): id of the sink (dependant on gateway)
        rx_time_ms_epoch(int): timestamp in ms of message reception relative to epoch
        src(int): source address
        dst(int): destination address
        src_ep(int): source endpoint
        dst_ep(int): destination endpoint
        travel_time_ms(int): travel time of the packet in the Wirepas network
        qos(int): Wirepas QOS used by sender for this message
        data(bytearray): the received data or None if must be hidden
        data_size(int): the received data size, only needed if data is None
        event_id(int): event unique id (random value generated if None)
        hop_count(int): number of hop for the message to reach the gateway
        network_address(int): network_address of this message
    """

    def __init__(
        self,
        gw_id,
        sink_id,
        rx_time_ms_epoch,
        src,
        dst,
        src_ep,
        dst_ep,
        travel_time_ms,
        qos,
        data=None,
        data_size=None,
        event_id=None,
        hop_count=0,
        network_address=None,
        **kwargs
    ):
        super(ReceivedDataEvent, self).__init__(
            gw_id, sink_id, event_id=event_id, **kwargs
        )
        self.sink_id = sink_id
        self.rx_time_ms_epoch = rx_time_ms_epoch
        self.source_address = src
        self.destination_address = dst
        self.source_endpoint = src_ep
        self.destination_endpoint = dst_ep
        self.travel_time_ms = travel_time_ms
        self.qos = qos
        if data is not None:
            self.data_payload = bytes(data)
        else:
            self.data_payload = None

        self.data_size = data_size
        self.hop_count = hop_count
        self.network_address = network_address

    @classmethod
    def from_payload(cls, payload):
        message = GenericMessage()
        try:
            message.ParseFromString(payload)
        except Exception:
            # Any Exception is promoted to Generic API exception
            raise GatewayAPIParsingException("Cannot parse ReceivedDataEvent payload")

        event = message.wirepas.packet_received_event
        d = Event._parse_event_header(event.header)

        # Check optional hop count field
        try:
            hop_count = event.hop_count
        except AttributeError:
            # Attribute is not defined
            hop_count = 0

        # Check optional payload field
        if event.HasField("payload"):
            payload = event.payload
        else:
            payload = None

        # Check optional payload field
        if event.HasField("payload_size"):
            payload_size = event.payload_size
        else:
            # Attribute is not defined
            payload_size = None

        # Check optional network_address field
        if event.HasField("network_address"):
            network_address = event.network_address
        else:
            # Network address is not set
            network_address = None

        return cls(
            d["gw_id"],
            d["sink_id"],
            event.rx_time_ms_epoch,
            event.source_address,
            event.destination_address,
            event.source_endpoint,
            event.destination_endpoint,
            event.travel_time_ms,
            event.qos,
            data=payload,
            data_size=payload_size,
            event_id=d["event_id"],
            hop_count=hop_count,
            network_address=network_address
        )

    @property
    def payload(self):
        message = GenericMessage()
        # Fill the event header
        event = message.wirepas.packet_received_event
        self._load_event_header(event)

        event.source_address = self.source_address
        event.destination_address = self.destination_address
        event.source_endpoint = self.source_endpoint
        event.destination_endpoint = self.destination_endpoint
        event.travel_time_ms = self.travel_time_ms
        event.rx_time_ms_epoch = self.rx_time_ms_epoch
        event.qos = self.qos

        if self.data_payload is not None:
            event.payload = self.data_payload

        if self.data_size is not None:
            event.payload_size = self.data_size

        if self.hop_count > 0:
            event.hop_count = self.hop_count

        if self.network_address is not None:
            event.network_address = self.network_address

        return message.SerializeToString()



"""
    Status
    ======

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

import enum
from .proto import GenericMessage, ON, OFF

from .event import Event
from .wirepas_exceptions import GatewayAPIParsingException

# This API should never be changes in future (prupose of protobuf)
API_VERSION = 1


class GatewayState(enum.Enum):
    """
    GatewayState

    Enum providing the possible
    states for the gateway

    ONLINE or OFFLINE

    """

    ONLINE = 0
    OFFLINE = 1


class StatusEvent(Event):
    """
    StatusEvent: Event generated by the gateway to set its sttaus (ONLINE/OFFLINE)

    Attributes:
        gw_id (str): gw_id (str): gateway unique identifier
        state (GatewayState): state of the gateway
        version (int): API version for gateway. Should be always 1
        event_id(int): event unique id (random value generated if None)
    """

    def __init__(self, gw_id, state, version=API_VERSION, event_id=None, **kwargs):
        super(StatusEvent, self).__init__(gw_id, event_id=event_id, **kwargs)
        self.state = state
        self.version = version

    @classmethod
    def from_payload(cls, payload):
        """ Converts a protobuff message into a python object """
        message = GenericMessage()
        try:
            message.ParseFromString(payload)
        except Exception:
            # Any Exception is promoted to Generic API exception
            raise GatewayAPIParsingException("Cannot parse StatusEvent payload")

        event = message.wirepas.status_event

        if event.state == ON:
            online = GatewayState.ONLINE
        else:
            online = GatewayState.OFFLINE

        if event.version != API_VERSION:
            raise RuntimeError("Wrong API version")

        d = Event._parse_event_header(event.header)
        return cls(d["gw_id"], online, event_id=d["event_id"])

    @property
    def payload(self):
        """ Returns a proto serialization of itself """

        message = GenericMessage()
        # Fill the request header
        status = message.wirepas.status_event
        self._load_event_header(status)

        status.version = API_VERSION
        if self.state == GatewayState.ONLINE:
            status.state = ON
        else:
            status.state = OFF

        return message.SerializeToString()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: error.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='error.proto',
  package='wirepas.proto.gateway_api',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0b\x65rror.proto\x12\x19wirepas.proto.gateway_api*\xe5\x05\n\tErrorCode\x12\x1f\n\x12UNKNOWN_ERROR_CODE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x06\n\x02OK\x10\x00\x12\x12\n\x0eINTERNAL_ERROR\x10\x01\x12\x13\n\x0fINVALID_SINK_ID\x10\x02\x12\x10\n\x0cINVALID_ROLE\x10\x03\x12\x1b\n\x17INVALID_NETWORK_ADDRESS\x10\x04\x12\x1b\n\x17INVALID_NETWORK_CHANNEL\x10\x05\x12\x17\n\x13INVALID_CHANNEL_MAP\x10\x06\x12\x18\n\x14INVALID_NETWORK_KEYS\x10\x07\x12\x14\n\x10INVALID_AC_RANGE\x10\x08\x12\x16\n\x12INVALID_SINK_STATE\x10\t\x12\x18\n\x14INVALID_DEST_ADDRESS\x10\n\x12\x19\n\x15INVALID_DEST_ENDPOINT\x10\x0b\x12\x18\n\x14INVALID_SRC_ENDPOINT\x10\x0c\x12\x0f\n\x0bINVALID_QOS\x10\r\x12\x18\n\x14INVALID_DATA_PAYLOAD\x10\x0e\x12\x16\n\x12INVALID_SCRATCHPAD\x10\x0f\x12\x1b\n\x17INVALID_SCRATCHPAD_SIZE\x10\x10\x12\x1b\n\x17INVLAID_SEQUENCE_NUMBER\x10\x11\x12\x1b\n\x17INVALID_SEQUENCE_NUMBER\x10\x11\x12\x18\n\x14INVALID_REBOOT_DELAY\x10\x12\x12\x19\n\x15INVALID_DIAG_INTERVAL\x10\x13\x12\x16\n\x12INVALID_APP_CONFIG\x10\x14\x12\x11\n\rINVALID_PARAM\x10\x15\x12\x19\n\x15NO_SCRATCHPAD_PRESENT\x10\x16\x12\x11\n\rACCESS_DENIED\x10\x17\x12\x19\n\x15REQUEST_NEEDS_SINK_ID\x10\x18\x12\x19\n\x15INVALID_MAX_HOP_COUNT\x10\x19\x12\x16\n\x12SINK_OUT_OF_MEMORY\x10\x1a\x12\x10\n\x0cSINK_TIMEOUT\x10\x1b\x1a\x02\x10\x01'
)

_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='wirepas.proto.gateway_api.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR_CODE', index=0, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SINK_ID', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ROLE', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NETWORK_ADDRESS', index=5, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NETWORK_CHANNEL', index=6, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CHANNEL_MAP', index=7, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NETWORK_KEYS', index=8, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_AC_RANGE', index=9, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SINK_STATE', index=10, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DEST_ADDRESS', index=11, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DEST_ENDPOINT', index=12, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SRC_ENDPOINT', index=13, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_QOS', index=14, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DATA_PAYLOAD', index=15, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SCRATCHPAD', index=16, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SCRATCHPAD_SIZE', index=17, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVLAID_SEQUENCE_NUMBER', index=18, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SEQUENCE_NUMBER', index=19, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REBOOT_DELAY', index=20, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DIAG_INTERVAL', index=21, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_APP_CONFIG', index=22, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PARAM', index=23, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_SCRATCHPAD_PRESENT', index=24, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCESS_DENIED', index=25, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REQUEST_NEEDS_SINK_ID', index=26, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MAX_HOP_COUNT', index=27, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINK_OUT_OF_MEMORY', index=28, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINK_TIMEOUT', index=29, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\020\001',
  serialized_start=43,
  serialized_end=784,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
UNKNOWN_ERROR_CODE = -1
OK = 0
INTERNAL_ERROR = 1
INVALID_SINK_ID = 2
INVALID_ROLE = 3
INVALID_NETWORK_ADDRESS = 4
INVALID_NETWORK_CHANNEL = 5
INVALID_CHANNEL_MAP = 6
INVALID_NETWORK_KEYS = 7
INVALID_AC_RANGE = 8
INVALID_SINK_STATE = 9
INVALID_DEST_ADDRESS = 10
INVALID_DEST_ENDPOINT = 11
INVALID_SRC_ENDPOINT = 12
INVALID_QOS = 13
INVALID_DATA_PAYLOAD = 14
INVALID_SCRATCHPAD = 15
INVALID_SCRATCHPAD_SIZE = 16
INVLAID_SEQUENCE_NUMBER = 17
INVALID_SEQUENCE_NUMBER = 17
INVALID_REBOOT_DELAY = 18
INVALID_DIAG_INTERVAL = 19
INVALID_APP_CONFIG = 20
INVALID_PARAM = 21
NO_SCRATCHPAD_PRESENT = 22
ACCESS_DENIED = 23
REQUEST_NEEDS_SINK_ID = 24
INVALID_MAX_HOP_COUNT = 25
SINK_OUT_OF_MEMORY = 26
SINK_TIMEOUT = 27


DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


_ERRORCODE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import wp_global_pb2 as wp__global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='config_message.proto',
  package='wirepas.proto.gateway_api',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14\x63onfig_message.proto\x12\x19wirepas.proto.gateway_api\x1a\x0fwp_global.proto\"\xe2\x01\n\x08NodeRole\x12:\n\x04role\x18\x01 \x02(\x0e\x32,.wirepas.proto.gateway_api.NodeRole.BaseRole\x12<\n\x05\x66lags\x18\x02 \x03(\x0e\x32-.wirepas.proto.gateway_api.NodeRole.RoleFlags\"0\n\x08\x42\x61seRole\x12\x08\n\x04SINK\x10\x01\x12\n\n\x06ROUTER\x10\x02\x12\x0e\n\nNON_ROUTER\x10\x03\"*\n\tRoleFlags\x12\x0f\n\x0bLOW_LATENCY\x10\x01\x12\x0c\n\x08\x41UTOROLE\x10\x02\"2\n\x10\x41\x63\x63\x65ssCycleRange\x12\x0e\n\x06min_ms\x18\x01 \x02(\r\x12\x0e\n\x06max_ms\x18\x02 \x02(\r\"8\n\x0c\x43hannelRange\x12\x13\n\x0bmin_channel\x18\x01 \x02(\r\x12\x13\n\x0bmax_channel\x18\x02 \x02(\r\"N\n\rAppConfigData\x12\x17\n\x0f\x64iag_interval_s\x18\x01 \x02(\r\x12\x17\n\x0f\x61pp_config_data\x18\x02 \x02(\x0c\x12\x0b\n\x03seq\x18\x03 \x02(\r\"5\n\x0bNetworkKeys\x12\x0e\n\x06\x63ipher\x18\x01 \x02(\x0c\x12\x16\n\x0e\x61uthentication\x18\x02 \x02(\x0c\"\xaa\x05\n\x0eSinkReadConfig\x12\x0f\n\x07sink_id\x18\x01 \x02(\t\x12\x36\n\tnode_role\x18\x02 \x01(\x0b\x32#.wirepas.proto.gateway_api.NodeRole\x12\x14\n\x0cnode_address\x18\x03 \x01(\r\x12\x17\n\x0fnetwork_address\x18\x04 \x01(\x04\x12\x17\n\x0fnetwork_channel\x18\x05 \x01(\r\x12<\n\napp_config\x18\x06 \x01(\x0b\x32(.wirepas.proto.gateway_api.AppConfigData\x12\x13\n\x0b\x63hannel_map\x18\x07 \x01(\r\x12\x14\n\x0c\x61re_keys_set\x18\x08 \x01(\x08\x12\x45\n\x10\x63urrent_ac_range\x18\t \x01(\x0b\x32+.wirepas.proto.gateway_api.AccessCycleRange\x12>\n\tac_limits\x18\n \x01(\x0b\x32+.wirepas.proto.gateway_api.AccessCycleRange\x12\x0f\n\x07max_mtu\x18\x0b \x01(\r\x12?\n\x0e\x63hannel_limits\x18\x0c \x01(\x0b\x32\'.wirepas.proto.gateway_api.ChannelRange\x12\x10\n\x08hw_magic\x18\r \x01(\r\x12\x15\n\rstack_profile\x18\x0e \x01(\r\x12\x1b\n\x13\x61pp_config_max_size\x18\x0f \x01(\r\x12\x44\n\x10\x66irmware_version\x18\x10 \x01(\x0b\x32*.wirepas.proto.gateway_api.FirmwareVersion\x12\x39\n\nsink_state\x18\x11 \x01(\x0e\x32%.wirepas.proto.gateway_api.OnOffState\"\xab\x03\n\rSinkNewConfig\x12\x0f\n\x07sink_id\x18\x01 \x02(\t\x12\x36\n\tnode_role\x18\x02 \x01(\x0b\x32#.wirepas.proto.gateway_api.NodeRole\x12\x14\n\x0cnode_address\x18\x03 \x01(\r\x12\x17\n\x0fnetwork_address\x18\x04 \x01(\x04\x12\x17\n\x0fnetwork_channel\x18\x05 \x01(\r\x12<\n\napp_config\x18\x06 \x01(\x0b\x32(.wirepas.proto.gateway_api.AppConfigData\x12\x13\n\x0b\x63hannel_map\x18\x07 \x01(\r\x12\x34\n\x04keys\x18\x08 \x01(\x0b\x32&.wirepas.proto.gateway_api.NetworkKeys\x12\x45\n\x10\x63urrent_ac_range\x18\t \x01(\x0b\x32+.wirepas.proto.gateway_api.AccessCycleRange\x12\x39\n\nsink_state\x18\n \x01(\x0e\x32%.wirepas.proto.gateway_api.OnOffState\"r\n\x0bGatewayInfo\x12\x1c\n\x14\x63urrent_time_s_epoch\x18\x01 \x02(\x04\x12\x10\n\x08gw_model\x18\x02 \x01(\t\x12\x12\n\ngw_version\x18\x03 \x01(\t\x12\x1f\n\x17implemented_api_version\x18\x04 \x01(\r\"\x8c\x01\n\x0bStatusEvent\x12\x36\n\x06header\x18\x01 \x02(\x0b\x32&.wirepas.proto.gateway_api.EventHeader\x12\x0f\n\x07version\x18\x02 \x02(\r\x12\x34\n\x05state\x18\x03 \x02(\x0e\x32%.wirepas.proto.gateway_api.OnOffState\"I\n\rGetConfigsReq\x12\x38\n\x06header\x18\x01 \x02(\x0b\x32(.wirepas.proto.gateway_api.RequestHeader\"\x87\x01\n\x0eGetConfigsResp\x12\x39\n\x06header\x18\x01 \x02(\x0b\x32).wirepas.proto.gateway_api.ResponseHeader\x12:\n\x07\x63onfigs\x18\x02 \x03(\x0b\x32).wirepas.proto.gateway_api.SinkReadConfig\"\x82\x01\n\x0cSetConfigReq\x12\x38\n\x06header\x18\x01 \x02(\x0b\x32(.wirepas.proto.gateway_api.RequestHeader\x12\x38\n\x06\x63onfig\x18\x02 \x02(\x0b\x32(.wirepas.proto.gateway_api.SinkNewConfig\"\x85\x01\n\rSetConfigResp\x12\x39\n\x06header\x18\x01 \x02(\x0b\x32).wirepas.proto.gateway_api.ResponseHeader\x12\x39\n\x06\x63onfig\x18\x02 \x02(\x0b\x32).wirepas.proto.gateway_api.SinkReadConfig\"H\n\x0cGetGwInfoReq\x12\x38\n\x06header\x18\x01 \x02(\x0b\x32(.wirepas.proto.gateway_api.RequestHeader\"\x80\x01\n\rGetGwInfoResp\x12\x39\n\x06header\x18\x01 \x02(\x0b\x32).wirepas.proto.gateway_api.ResponseHeader\x12\x34\n\x04info\x18\x02 \x02(\x0b\x32&.wirepas.proto.gateway_api.GatewayInfo'
  ,
  dependencies=[wp__global__pb2.DESCRIPTOR,])



_NODEROLE_BASEROLE = _descriptor.EnumDescriptor(
  name='BaseRole',
  full_name='wirepas.proto.gateway_api.NodeRole.BaseRole',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SINK', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTER', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NON_ROUTER', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=203,
  serialized_end=251,
)
_sym_db.RegisterEnumDescriptor(_NODEROLE_BASEROLE)

_NODEROLE_ROLEFLAGS = _descriptor.EnumDescriptor(
  name='RoleFlags',
  full_name='wirepas.proto.gateway_api.NodeRole.RoleFlags',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW_LATENCY', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTOROLE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=253,
  serialized_end=295,
)
_sym_db.RegisterEnumDescriptor(_NODEROLE_ROLEFLAGS)


_NODEROLE = _descriptor.Descriptor(
  name='NodeRole',
  full_name='wirepas.proto.gateway_api.NodeRole',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role', full_name='wirepas.proto.gateway_api.NodeRole.role', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='wirepas.proto.gateway_api.NodeRole.flags', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NODEROLE_BASEROLE,
    _NODEROLE_ROLEFLAGS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=295,
)


_ACCESSCYCLERANGE = _descriptor.Descriptor(
  name='AccessCycleRange',
  full_name='wirepas.proto.gateway_api.AccessCycleRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_ms', full_name='wirepas.proto.gateway_api.AccessCycleRange.min_ms', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ms', full_name='wirepas.proto.gateway_api.AccessCycleRange.max_ms', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=347,
)


_CHANNELRANGE = _descriptor.Descriptor(
  name='ChannelRange',
  full_name='wirepas.proto.gateway_api.ChannelRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_channel', full_name='wirepas.proto.gateway_api.ChannelRange.min_channel', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_channel', full_name='wirepas.proto.gateway_api.ChannelRange.max_channel', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=405,
)


_APPCONFIGDATA = _descriptor.Descriptor(
  name='AppConfigData',
  full_name='wirepas.proto.gateway_api.AppConfigData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='diag_interval_s', full_name='wirepas.proto.gateway_api.AppConfigData.diag_interval_s', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_config_data', full_name='wirepas.proto.gateway_api.AppConfigData.app_config_data', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='wirepas.proto.gateway_api.AppConfigData.seq', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=485,
)


_NETWORKKEYS = _descriptor.Descriptor(
  name='NetworkKeys',
  full_name='wirepas.proto.gateway_api.NetworkKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cipher', full_name='wirepas.proto.gateway_api.NetworkKeys.cipher', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authentication', full_name='wirepas.proto.gateway_api.NetworkKeys.authentication', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=540,
)


_SINKREADCONFIG = _descriptor.Descriptor(
  name='SinkReadConfig',
  full_name='wirepas.proto.gateway_api.SinkReadConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='wirepas.proto.gateway_api.SinkReadConfig.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_role', full_name='wirepas.proto.gateway_api.SinkReadConfig.node_role', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_address', full_name='wirepas.proto.gateway_api.SinkReadConfig.node_address', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_address', full_name='wirepas.proto.gateway_api.SinkReadConfig.network_address', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_channel', full_name='wirepas.proto.gateway_api.SinkReadConfig.network_channel', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_config', full_name='wirepas.proto.gateway_api.SinkReadConfig.app_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_map', full_name='wirepas.proto.gateway_api.SinkReadConfig.channel_map', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='are_keys_set', full_name='wirepas.proto.gateway_api.SinkReadConfig.are_keys_set', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_ac_range', full_name='wirepas.proto.gateway_api.SinkReadConfig.current_ac_range', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ac_limits', full_name='wirepas.proto.gateway_api.SinkReadConfig.ac_limits', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_mtu', full_name='wirepas.proto.gateway_api.SinkReadConfig.max_mtu', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_limits', full_name='wirepas.proto.gateway_api.SinkReadConfig.channel_limits', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hw_magic', full_name='wirepas.proto.gateway_api.SinkReadConfig.hw_magic', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stack_profile', full_name='wirepas.proto.gateway_api.SinkReadConfig.stack_profile', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_config_max_size', full_name='wirepas.proto.gateway_api.SinkReadConfig.app_config_max_size', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firmware_version', full_name='wirepas.proto.gateway_api.SinkReadConfig.firmware_version', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sink_state', full_name='wirepas.proto.gateway_api.SinkReadConfig.sink_state', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=1225,
)


_SINKNEWCONFIG = _descriptor.Descriptor(
  name='SinkNewConfig',
  full_name='wirepas.proto.gateway_api.SinkNewConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sink_id', full_name='wirepas.proto.gateway_api.SinkNewConfig.sink_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_role', full_name='wirepas.proto.gateway_api.SinkNewConfig.node_role', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_address', full_name='wirepas.proto.gateway_api.SinkNewConfig.node_address', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_address', full_name='wirepas.proto.gateway_api.SinkNewConfig.network_address', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_channel', full_name='wirepas.proto.gateway_api.SinkNewConfig.network_channel', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_config', full_name='wirepas.proto.gateway_api.SinkNewConfig.app_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_map', full_name='wirepas.proto.gateway_api.SinkNewConfig.channel_map', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keys', full_name='wirepas.proto.gateway_api.SinkNewConfig.keys', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_ac_range', full_name='wirepas.proto.gateway_api.SinkNewConfig.current_ac_range', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sink_state', full_name='wirepas.proto.gateway_api.SinkNewConfig.sink_state', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1228,
  serialized_end=1655,
)


_GATEWAYINFO = _descriptor.Descriptor(
  name='GatewayInfo',
  full_name='wirepas.proto.gateway_api.GatewayInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_time_s_epoch', full_name='wirepas.proto.gateway_api.GatewayInfo.current_time_s_epoch', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gw_model', full_name='wirepas.proto.gateway_api.GatewayInfo.gw_model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gw_version', full_name='wirepas.proto.gateway_api.GatewayInfo.gw_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implemented_api_version', full_name='wirepas.proto.gateway_api.GatewayInfo.implemented_api_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1657,
  serialized_end=1771,
)


_STATUSEVENT = _descriptor.Descriptor(
  name='StatusEvent',
  full_name='wirepas.proto.gateway_api.StatusEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.StatusEvent.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='wirepas.proto.gateway_api.StatusEvent.version', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='wirepas.proto.gateway_api.StatusEvent.state', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1774,
  serialized_end=1914,
)


_GETCONFIGSREQ = _descriptor.Descriptor(
  name='GetConfigsReq',
  full_name='wirepas.proto.gateway_api.GetConfigsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.GetConfigsReq.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=1989,
)


_GETCONFIGSRESP = _descriptor.Descriptor(
  name='GetConfigsResp',
  full_name='wirepas.proto.gateway_api.GetConfigsResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.GetConfigsResp.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configs', full_name='wirepas.proto.gateway_api.GetConfigsResp.configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1992,
  serialized_end=2127,
)


_SETCONFIGREQ = _descriptor.Descriptor(
  name='SetConfigReq',
  full_name='wirepas.proto.gateway_api.SetConfigReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.SetConfigReq.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='wirepas.proto.gateway_api.SetConfigReq.config', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2130,
  serialized_end=2260,
)


_SETCONFIGRESP = _descriptor.Descriptor(
  name='SetConfigResp',
  full_name='wirepas.proto.gateway_api.SetConfigResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.SetConfigResp.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='wirepas.proto.gateway_api.SetConfigResp.config', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2263,
  serialized_end=2396,
)


_GETGWINFOREQ = _descriptor.Descriptor(
  name='GetGwInfoReq',
  full_name='wirepas.proto.gateway_api.GetGwInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.GetGwInfoReq.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2398,
  serialized_end=2470,
)


_GETGWINFORESP = _descriptor.Descriptor(
  name='GetGwInfoResp',
  full_name='wirepas.proto.gateway_api.GetGwInfoResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='wirepas.proto.gateway_api.GetGwInfoResp.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='wirepas.proto.gateway_api.GetGwInfoResp.info', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2473,
  serialized_end=2601,
)

_NODEROLE.fields_by_name['role'].enum_type = _NODEROLE_BASEROLE
_NODEROLE.fields_by_name['flags'].enum_type = _NODEROLE_ROLEFLAGS
_NODEROLE_BASEROLE.containing_type = _NODEROLE
_NODEROLE_ROLEFLAGS.containing_type = _NODEROLE
_SINKREADCONFIG.fields_by_name['node_role'].message_type = _NODEROLE
_SINKREADCONFIG.fields_by_name['app_config'].message_type = _APPCONFIGDATA
_SINKREADCONFIG.fields_by_name['current_ac_range'].message_type = _ACCESSCYCLERANGE
_SINKREADCONFIG.fields_by_name['ac_limits'].message_type = _ACCESSCYCLERANGE
_SINKREADCONFIG.fields_by_name['channel_limits'].message_type = _CHANNELRANGE
_SINKREADCONFIG.fields_by_name['firmware_version'].message_type = wp__global__pb2._FIRMWAREVERSION
_SINKREADCONFIG.fields_by_name['sink_state'].enum_type = wp__global__pb2._ONOFFSTATE
_SINKNEWCONFIG.fields_by_name['node_role'].message_type = _NODEROLE
_SINKNEWCONFIG.fields_by_name['app_config'].message_type = _APPCONFIGDATA
_SINKNEWCONFIG.fields_by_name['keys'].message_type = _NETWORKKEYS
_SINKNEWCONFIG.fields_by_name['current_ac_range'].message_type = _ACCESSCYCLERANGE
_SINKNEWCONFIG.fields_by_name['sink_state'].enum_type = wp__global__pb2._ONOFFSTATE
_STATUSEVENT.fields_by_name['header'].message_type = wp__global__pb2._EVENTHEADER
_STATUSEVENT.fields_by_name['state'].enum_type = wp__global__pb2._ONOFFSTATE
_GETCONFIGSREQ.fields_by_name['header'].message_type = wp__global__pb2._REQUESTHEADER
_GETCONFIGSRESP.fields_by_name['header'].message_type = wp__global__pb2._RESPONSEHEADER
_GETCONFIGSRESP.fields_by_name['configs'].message_type = _SINKREADCONFIG
_SETCONFIGREQ.fields_by_name['header'].message_type = wp__global__pb2._REQUESTHEADER
_SETCONFIGREQ.fields_by_name['config'].message_type = _SINKNEWCONFIG
_SETCONFIGRESP.fields_by_name['header'].message_type = wp__global__pb2._RESPONSEHEADER
_SETCONFIGRESP.fields_by_name['config'].message_type = _SINKREADCONFIG
_GETGWINFOREQ.fields_by_name['header'].message_type = wp__global__pb2._REQUESTHEADER
_GETGWINFORESP.fields_by_name['header'].message_type = wp__global__pb2._RESPONSEHEADER
_GETGWINFORESP.fields_by_name['info'].message_type = _GATEWAYINFO
DESCRIPTOR.message_types_by_name['NodeRole'] = _NODEROLE
DESCRIPTOR.message_types_by_name['AccessCycleRange'] = _ACCESSCYCLERANGE
DESCRIPTOR.message_types_by_name['ChannelRange'] = _CHANNELRANGE
DESCRIPTOR.message_types_by_name['AppConfigData'] = _APPCONFIGDATA
DESCRIPTOR.message_types_by_name['NetworkKeys'] = _NETWORKKEYS
DESCRIPTOR.message_types_by_name['SinkReadConfig'] = _SINKREADCONFIG
DESCRIPTOR.message_types_by_name['SinkNewConfig'] = _SINKNEWCONFIG
DESCRIPTOR.message_types_by_name['GatewayInfo'] = _GATEWAYINFO
DESCRIPTOR.message_types_by_name['StatusEvent'] = _STATUSEVENT
DESCRIPTOR.message_types_by_name['GetConfigsReq'] = _GETCONFIGSREQ
DESCRIPTOR.message_types_by_name['GetConfigsResp'] = _GETCONFIGSRESP
DESCRIPTOR.message_types_by_name['SetConfigReq'] = _SETCONFIGREQ
DESCRIPTOR.message_types_by_name['SetConfigResp'] = _SETCONFIGRESP
DESCRIPTOR.message_types_by_name['GetGwInfoReq'] = _GETGWINFOREQ
DESCRIPTOR.message_types_by_name['GetGwInfoResp'] = _GETGWINFORESP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NodeRole = _reflection.GeneratedProtocolMessageType('NodeRole', (_message.Message,), {
  'DESCRIPTOR' : _NODEROLE,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.NodeRole)
  })
_sym_db.RegisterMessage(NodeRole)

AccessCycleRange = _reflection.GeneratedProtocolMessageType('AccessCycleRange', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSCYCLERANGE,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.AccessCycleRange)
  })
_sym_db.RegisterMessage(AccessCycleRange)

ChannelRange = _reflection.GeneratedProtocolMessageType('ChannelRange', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELRANGE,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.ChannelRange)
  })
_sym_db.RegisterMessage(ChannelRange)

AppConfigData = _reflection.GeneratedProtocolMessageType('AppConfigData', (_message.Message,), {
  'DESCRIPTOR' : _APPCONFIGDATA,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.AppConfigData)
  })
_sym_db.RegisterMessage(AppConfigData)

NetworkKeys = _reflection.GeneratedProtocolMessageType('NetworkKeys', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKKEYS,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.NetworkKeys)
  })
_sym_db.RegisterMessage(NetworkKeys)

SinkReadConfig = _reflection.GeneratedProtocolMessageType('SinkReadConfig', (_message.Message,), {
  'DESCRIPTOR' : _SINKREADCONFIG,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.SinkReadConfig)
  })
_sym_db.RegisterMessage(SinkReadConfig)

SinkNewConfig = _reflection.GeneratedProtocolMessageType('SinkNewConfig', (_message.Message,), {
  'DESCRIPTOR' : _SINKNEWCONFIG,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.SinkNewConfig)
  })
_sym_db.RegisterMessage(SinkNewConfig)

GatewayInfo = _reflection.GeneratedProtocolMessageType('GatewayInfo', (_message.Message,), {
  'DESCRIPTOR' : _GATEWAYINFO,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.GatewayInfo)
  })
_sym_db.RegisterMessage(GatewayInfo)

StatusEvent = _reflection.GeneratedProtocolMessageType('StatusEvent', (_message.Message,), {
  'DESCRIPTOR' : _STATUSEVENT,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.StatusEvent)
  })
_sym_db.RegisterMessage(StatusEvent)

GetConfigsReq = _reflection.GeneratedProtocolMessageType('GetConfigsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGSREQ,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.GetConfigsReq)
  })
_sym_db.RegisterMessage(GetConfigsReq)

GetConfigsResp = _reflection.GeneratedProtocolMessageType('GetConfigsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGSRESP,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.GetConfigsResp)
  })
_sym_db.RegisterMessage(GetConfigsResp)

SetConfigReq = _reflection.GeneratedProtocolMessageType('SetConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQ,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.SetConfigReq)
  })
_sym_db.RegisterMessage(SetConfigReq)

SetConfigResp = _reflection.GeneratedProtocolMessageType('SetConfigResp', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESP,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.SetConfigResp)
  })
_sym_db.RegisterMessage(SetConfigResp)

GetGwInfoReq = _reflection.GeneratedProtocolMessageType('GetGwInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _GETGWINFOREQ,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.GetGwInfoReq)
  })
_sym_db.RegisterMessage(GetGwInfoReq)

GetGwInfoResp = _reflection.GeneratedProtocolMessageType('GetGwInfoResp', (_message.Message,), {
  'DESCRIPTOR' : _GETGWINFORESP,
  '__module__' : 'config_message_pb2'
  # @@protoc_insertion_point(class_scope:wirepas.proto.gateway_api.GetGwInfoResp)
  })
_sym_db.RegisterMessage(GetGwInfoResp)


# @@protoc_insertion_point(module_scope)



"""
    Send data
    =========

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

from .proto import GenericMessage

from .request import Request
from .response import Response

from .wirepas_exceptions import GatewayAPIParsingException


class SendDataRequest(Request):
    """
    SendDataRequest: request to send data from a given sink

    Attributes:
        dest_add(int): destination address
        src_ep(int): source endpoint
        dst_ep(int): destination endpoint
        qos(int): Wirepas QOS to use for this message
        payload(bytearray): the data to send
        initial_delay_ms(int): initial delay to add to travel time
        sink_id (str): id of the sink (dependant on gateway)
        req_id (int): unique request id
        is_unack_csma_ca(bool): if true only sent to CB-MAC nodes
        hop_limit(int): maximum number of hops this message can do to reach its destination (<16)
    """

    def __init__(
        self,
        dest_add,
        src_ep,
        dst_ep,
        qos,
        payload,
        initial_delay_ms=0,
        sink_id=None,
        req_id=None,
        is_unack_csma_ca=False,
        hop_limit=0,
        **kwargs
    ):
        super(SendDataRequest, self).__init__(sink_id, req_id, **kwargs)
        self.destination_address = dest_add
        self.source_endpoint = src_ep
        self.destination_endpoint = dst_ep
        self.qos = qos
        self.data_payload = payload
        self.initial_delay_ms = initial_delay_ms
        self.is_unack_csma_ca = is_unack_csma_ca
        self.hop_limit = hop_limit

    @classmethod
    def from_payload(cls, payload):
        message = GenericMessage()
        try:
            message.ParseFromString(payload)
        except Exception:
            # Any Exception is promoted to Generic API exception
            raise GatewayAPIParsingException("Cannot parse SendDataRequest payload")

        req = message.wirepas.send_packet_req
        d = Request._parse_request_header(req.header)

        # Handle optional fields
        try:
            initial_delay_ms = req.initial_delay_ms
        except AttributeError:
            # Attribute is not defined
            initial_delay_ms = 0

        try:
            is_unack_csma_ca = req.is_unack_csma_ca
        except AttributeError:
            # Attribute is not defined
            is_unack_csma_ca = False

        try:
            hop_limit = req.hop_limit
        except AttributeError:
            # Attribute is not defined
            hop_limit = 0

        return cls(
            req.destination_address,
            req.source_endpoint,
            req.destination_endpoint,
            req.qos,
            req.payload,
            initial_delay_ms,
            d["sink_id"],
            d["req_id"],
            is_unack_csma_ca,
            hop_limit,
        )

    @property
    def payload(self):
        message = GenericMessage()

        # Fill the request header
        req = message.wirepas.send_packet_req
        self._load_request_header(req)

        req.destination_address = self.destination_address
        req.source_endpoint = self.source_endpoint
        req.destination_endpoint = self.destination_endpoint
        req.qos = self.qos

        req.payload = self.data_payload
        if self.initial_delay_ms > 0:
            req.initial_delay_ms = self.initial_delay_ms

        if self.is_unack_csma_ca:
            # Only set the optional field if True
            req.is_unack_csma_ca = self.is_unack_csma_ca

        if self.hop_limit > 0:
            req.hop_limit = self.hop_limit

        return message.SerializeToString()


class SendDataResponse(Response):
    """
     SendDataResponse: Response to answer a SendDataRequest

     Attributes:
         req_id (int): unique request id that this Response is associated
         gw_id (str): gateway unique identifier
         res (GatewayResultCode): result of the operation
         sink_id (str): id of the sink (dependant on gateway)
     """

    def __init__(self, req_id, gw_id, res, sink_id, **kwargs):
        super(SendDataResponse, self).__init__(req_id, gw_id, res, sink_id, **kwargs)

    @classmethod
    def from_payload(cls, payload):
        message = GenericMessage()
        try:
            message.ParseFromString(payload)
        except Exception:
            # Any Exception is promoted to Generic API exception
            raise GatewayAPIParsingException("Cannot parse SendDataResponse payload")

        response = message.wirepas.send_packet_resp

        d = Response._parse_response_header(response.header)

        return cls(d["req_id"], d["gw_id"], d["res"], d["sink_id"])

    @property
    def payload(self):
        message = GenericMessage()

        response = message.wirepas.send_packet_resp
        self._load_response_header(response)

        return message.SerializeToString()



"""
    .. Copyright:
        Copyright Wirepas Ltd 2019 licensed under Apache License, Version 2.0
        See file LICENSE for full license details.
"""

__author__ = "Wirepas Ltd"
__author_email__ = "opensource@wirepas.com"
__classifiers__ = [
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: Apache Software License",
    "Topic :: Software Development :: Libraries",
    "Programming Language :: Python :: 3",
]
__copyright__ = "2020 Wirepas Ltd"
__description__ = "Wrapper interfaces to interact with Backend to/from Gateway API."
__keywords__ = "wirepas connectivity iot mesh gateway backend"
__license__ = "Apache-2"
__pkg_name__ = "wirepas_mesh_messaging"
__title__ = "Wirepas Messaging For Mesh access"
__url__ = "https://github.com/wirepas/backend-apis/tree/master/gateway_to_backend"
__version__ = "1.1"
__warning_msg__ = """
***********************************************************************
* WARNING:
*     You are using the pure python protobuf implementation.
*     For better results, please consider using the cpp version.
*     For more information please consult:
*     https://github.com/protocolbuffers/protobuf/tree/master/python
***********************************************************************
"""



"""
    Get scratchpad status
    =====================

    .. Copyright:
        Copyright 2019 Wirepas Ltd under Apache License, Version 2.0.
        See file LICENSE for full license details.
"""

from .proto import GenericMessage

from .request import Request
from .response import Response

from .otap_helper import (
    set_scratchpad_info,
    parse_scratchpad_info,
    ScratchpadStatus,
    ScratchpadType, parse_scratchpad_target, set_scratchpad_target,
)
from .gateway_result_code import GatewayResultCode
from .wirepas_exceptions import GatewayAPIParsingException


class GetScratchpadStatusRequest(Request):
    """
    GetScratchpadStatusRequest: request to obtain scratchpad status of a given sink

    Attributes:
        sink_id (str): id of the sink (dependant on gateway)
        req_id (int): unique request id
    """

    def __init__(self, sink_id, req_id=None, **kwargs):
        super(GetScratchpadStatusRequest, self).__init__(sink_id, req_id, **kwargs)

    @classmethod
    def from_payload(cls, payload):
        message = GenericMessage()
        try:
            message.ParseFromString(payload)
        except Exception:
            # Any Exception is promoted to Generic API exception
            raise GatewayAPIParsingException(
                "Cannot parse GetScratchpadStatusRequest payload"
            )

        req = message.wirepas.get_scratchpad_status_req

        d = Request._parse_request_header(req.header)

        return cls(d["sink_id"], d["req_id"])

    @property
    def payload(self):
        message = GenericMessage()
        # Fill the request header
        req = message.wirepas.get_scratchpad_status_req
        self._load_request_header(req)

        return message.SerializeToString()


class GetScratchpadStatusResponse(Response):
    """
    GetScratchpadStatusResponse: Response to answer a GetScratchpadStatusRequest

    Attributes:
        req_id (int): unique request id that this Response is associated
        gw_id (str): gateway unique identifier
        res (GatewayResultCode): result of the operation
        sink_id (str): id of the sink (dependant on gateway)
        stored_scratchpad(dict): dictionary containing description of stored scratchpad
        stored_status(ScratchpadStatus): status of stored scratchpad
        stored_type(ScratchpadType): type of stored scratchpad
        process_scratchpad(dic): dictionary containing description of processed scratchpad
        target_scratchpad_and_action(dic): dictionary containing target scratchpad and associated action
        firmware_area_id(int): current firmware area id
    """

    def __init__(
        self,
        req_id,
        gw_id,
        res,
        sink_id,
        stored_scratchpad=None,
        stored_status=None,
        stored_type=None,
        processed_scratchpad=None,
        firmware_area_id=None,
        target_scratchpad_and_action=None,
        **kwargs
    ):
        super(GetScratchpadStatusResponse, self).__init__(req_id, gw_id, res, sink_id)
        self.stored_scratchpad = stored_scratchpad
        self.stored_status = stored_status
        self.stored_type = stored_type
        self.processed_scratchpad = processed_scratchpad
        self.firmware_area_id = firmware_area_id
        self.target_scratchpad_and_action = target_scratchpad_and_action

    @classmethod
    def from_payload(cls, payload):
        message = GenericMessage()
        try:
            message.ParseFromString(payload)
        except Exception:
            # Any Exception is promoted to Generic API exception
            raise GatewayAPIParsingException(
                "Cannot parse GetScratchpadStatusResponse payload"
            )

        response = message.wirepas.get_scratchpad_status_resp

        d = Response._parse_response_header(response.header)

        stored_scratchpad = None
        processed_scratchpad = None
        stored_status = None
        stored_type = None
        firmware_area_id = None
        target_scratchpad_and_action = None

        if response.HasField("stored_scratchpad"):
            stored_scratchpad = dict()
            parse_scratchpad_info(response.stored_scratchpad, stored_scratchpad)

        if response.HasField("processed_scratchpad"):
            processed_scratchpad = dict()
            parse_scratchpad_info(response.processed_scratchpad, processed_scratchpad)

        if response.HasField("stored_status"):
            stored_status = ScratchpadStatus(response.stored_status)

        if response.HasField("stored_type"):
            stored_type = ScratchpadType(response.stored_type)

        if response.HasField("firmware_area_id"):
            firmware_area_id = response.firmware_area_id

        if response.HasField("target_and_action"):
            target_scratchpad_and_action = dict()
            parse_scratchpad_target(response.target_and_action, target_scratchpad_and_action)

        return cls(
            d["req_id"],
            d["gw_id"],
            d["res"],
            d["sink_id"],
            stored_scratchpad,
            stored_status,
            stored_type,
            processed_scratchpad,
            firmware_area_id,
            target_scratchpad_and_action,
        )

    @property
    def payload(self):
        message = GenericMessage()

        response = message.wirepas.get_scratchpad_status_resp
        self._load_response_header(response)

        if self.res is not GatewayResultCode.GW_RES_OK:
            # Return code is not OK so do not send message
            return message.SerializeToString()

        if self.stored_scratchpad is not None:
            set_scratchpad_info(response.stored_scratchpad, self.stored_scratchpad)

        if self.processed_scratchpad is not None:
            set_scratchpad_info(
                response.processed_scratchpad, self.processed_scratchpad
            )

        if self.stored_status is not None:
            response.stored_status = self.stored_status.value

        if self.stored_type is not None:
            response.stored_type = self.stored_type.value

        if self.firmware_area_id is not None:
            response.firmware_area_id = self.firmware_area_id

        if self.target_scratchpad_and_action is not None:
            set_scratchpad_target(response.target_and_action, self.target_scratchpad_and_action)

        return message.SerializeToString()
